.. _detector_stacks:

********************************
Charged Particle Detector Stacks
********************************

.. currentmodule:: plasmapy.diagnostics.charged_particle_radiography.detector_stacks

.. automodapi:: plasmapy.diagnostics.charged_particle_radiography.detector_stacks

.. nbgallery::
    :caption: Examples

    /notebooks/diagnostics/charged_particle_radiography_film_stacks
